%define anolis_release 1

Name:           openscap
Version:        1.4.1
Release:        %{anolis_release}%{?dist}
Epoch:          1
Summary:        Set of open source libraries enabling integration of the SCAP line of standards
License:        LGPL-2.1-or-later
URL:            https://github.com/OpenSCAP/openscap
Source0:        https://github.com/OpenSCAP/openscap/releases/download/%{version}/openscap-%{version}.tar.gz

%global         common_description %{expand:
OpenSCAP is a set of open source libraries providing an easier path
for integration of the SCAP line of standards. SCAP is a line of standards
managed by NIST with the goal of providing a standard language
for the expression of Computer Network Defense related information.}
BuildRequires:  make
BuildRequires:  cmake >= 2.6
BuildRequires:  cmake-rpm-macros
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  swig libxml2-devel libxslt-devel perl-generators perl-XML-Parser
BuildRequires:  rpm-devel
BuildRequires:  nss-devel
BuildRequires:  pcre2-devel
BuildRequires:  libacl-devel
BuildRequires:  libselinux-devel
BuildRequires:  libcap-devel
BuildRequires:  libblkid-devel
BuildRequires:  bzip2-devel
BuildRequires:  asciidoc
BuildRequires:  openldap-devel
BuildRequires:  glib2-devel
BuildRequires:  dbus-devel
BuildRequires:  libyaml-devel
BuildRequires:  xmlsec1-devel xmlsec1-openssl-devel
BuildRequires:  systemd
%if %{?_with_check:1}%{!?_with_check:0}
BuildRequires:  perl-XML-XPath
BuildRequires:  bzip2
%endif
BuildRequires:  systemd-rpm-macros
BuildRequires:  procps-devel
BuildRequires:  python3-devel
Requires:       bash
Requires:       bzip2-libs
Requires:       dbus
Requires:       glib2
Requires:       libacl
Requires:       libblkid
Requires:       libcap
Requires:       libselinux
Requires:       openldap
Requires:       popt
# Fedora has procps-ng, which provides procps
Requires:       procps
Requires:       xmlsec1 xmlsec1-openssl

Obsoletes:      openscap-containers < 1:1.4.1
Obsoletes:      openscap-python3 < 1:1.4.1
Obsoletes:      openscap-devel < 1:1.4.1

%description %{common_description}

%package        scanner
Summary:        OpenSCAP Scanner Tool (oscap)
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       libcurl >= 7.12.0
BuildRequires:  libcurl-devel >= 7.12.0

%description    scanner
The %{name}-scanner package contains oscap command-line tool. The oscap
is configuration and vulnerability scanner, capable of performing
compliance checking using SCAP content.
%{common_description}

%package        utils
Summary:        OpenSCAP Utilities
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       rpmdevtools rpm-build
Requires:       %{name}-scanner = %{epoch}:%{version}-%{release}

%description    utils
The %{name}-utils package contains command-line tools build on top
of OpenSCAP library. Historically, openscap-utils included oscap
tool which is now separated to %{name}-scanner sub-package.
%{common_description}

%package        engine-sce
Summary:        Script Check Engine plug-in for OpenSCAP
Requires:       %{name} = %{epoch}:%{version}-%{release}

Obsoletes:      openscap-engine-sce-devel < 1:1.4.1

%description    engine-sce
The Script Check Engine is non-standard extension to SCAP protocol. This
engine allows content authors to avoid OVAL language and write their assessment
commands using a scripting language (Bash, Perl, Python, Ruby, ...).

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%cmake \
    -DWITH_CRYPTO=nss \
    -DENABLE_DOCS=ON \
    -DENABLE_PERL=OFF \
    -DENABLE_PYTHON3=OFF \
    -DENABLE_OSCAP_UTIL_DOCKER=OFF \
    -DENABLE_OSCAP_REMEDIATE_SERVICE=OFF \
    -DOPENSCAP_PROBE_LINUX_DPKGINFO=OFF \
    -DOPENSCAP_ENABLE_SHA1=OFF \
    -DOPENSCAP_ENABLE_MD5=OFF
%cmake_build
make docs

%install
%cmake_install

find %{buildroot} -name '*.la' -exec rm -f {} ';'

%generate_compatibility_deps

%files
%license COPYING
%doc %{_pkgdocdir}/manual/
%dir %{_datadir}/openscap
%dir %{_datadir}/openscap/schemas
%dir %{_datadir}/openscap/xsl
%dir %{_datadir}/openscap/cpe
%{_libdir}/libopenscap.so.*
%{_datadir}/openscap/schemas/*
%{_datadir}/openscap/xsl/*
%{_datadir}/openscap/cpe/*
%dir %{abidir}
%{abidir}/libopenscap.dump


%exclude %{_libdir}/libopenscap.so
%exclude %{_libdir}/pkgconfig/*.pc
%exclude %{_includedir}/openscap
%exclude %{_pkgdocdir}/html/


%files scanner
%{_mandir}/man8/oscap.8*
%{_bindir}/oscap
%{_mandir}/man8/oscap-chroot.8*
%{_bindir}/oscap-chroot
%{_sysconfdir}/bash_completion.d
%{abidir}/oscap-option.list
%{abidir}/oscap-chroot-option.list

%files utils
%doc docs/oscap-scan.cron
%{_mandir}/man8/*
%exclude %{_mandir}/man8/oscap.8*
%exclude %{_mandir}/man8/oscap-chroot.8*
%{_bindir}/*
%exclude %{_bindir}/oscap
%exclude %{_bindir}/oscap-chroot
%{abidir}/autotailor-option.list
%{abidir}/oscap-run-sce-script-option.list
%{abidir}/oscap-vm-option.list
%{abidir}/oscap-im-option.list
%{abidir}/oscap-podman-option.list

%files engine-sce
%{_libdir}/libopenscap_sce.so.*
%exclude %{_libdir}/libopenscap_sce.so
%{abidir}/libopenscap_sce.dump

%files doc
%doc AUTHORS NEWS README.md

%changelog
* Thu Feb 27 2025 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 1:1.4.1-1
- update to 1:1.4.1 from 1:1.3.7
- Migrated to SPDX license
- Use NSS as cryptography library
- Remove openscap-devel, openscap-engine-sce-devel and openscap-python3 subpackages

* Fri Mar 22 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1.3.7-2
- Rebuild with python3.11

* Wed Mar 15 2023 happy_orange <songnannan@linux.alibaba.com> - 1:1.3.7-1
- init package
